==> openshift-model-config-6.2.0-sources.jar: io/fabric8/openshift/api/model/config/v1/AWSPlatformSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface AWSPlatformSpecFluent<A extends AWSPlatformSpecFluent<A>> extends Fluent<A>{
  public A addToServiceEndpoints(Integer index,AWSServiceEndpoint item);
  public A setToServiceEndpoints(Integer index,AWSServiceEndpoint item);
  public A addToServiceEndpoints(io.fabric8.openshift.api.model.config.v1.AWSServiceEndpoint... items);
  public A addAllToServiceEndpoints(Collection<AWSServiceEndpoint> items);
  public A removeFromServiceEndpoints(io.fabric8.openshift.api.model.config.v1.AWSServiceEndpoint... items);
  public A removeAllFromServiceEndpoints(Collection<AWSServiceEndpoint> items);
  public A removeMatchingFromServiceEndpoints(Predicate<AWSServiceEndpointBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildServiceEndpoints instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<AWSServiceEndpoint> getServiceEndpoints();
  public List<AWSServiceEndpoint> buildServiceEndpoints();
  public AWSServiceEndpoint buildServiceEndpoint(Integer index);
  public AWSServiceEndpoint buildFirstServiceEndpoint();
  public AWSServiceEndpoint buildLastServiceEndpoint();
  public AWSServiceEndpoint buildMatchingServiceEndpoint(Predicate<AWSServiceEndpointBuilder> predicate);
  public Boolean hasMatchingServiceEndpoint(Predicate<AWSServiceEndpointBuilder> predicate);
  public A withServiceEndpoints(List<AWSServiceEndpoint> serviceEndpoints);
  public A withServiceEndpoints(io.fabric8.openshift.api.model.config.v1.AWSServiceEndpoint... serviceEndpoints);
  public Boolean hasServiceEndpoints();
  public A addNewServiceEndpoint(String name,String url);
  public AWSPlatformSpecFluent.ServiceEndpointsNested<A> addNewServiceEndpoint();
  public AWSPlatformSpecFluent.ServiceEndpointsNested<A> addNewServiceEndpointLike(AWSServiceEndpoint item);
  public AWSPlatformSpecFluent.ServiceEndpointsNested<A> setNewServiceEndpointLike(Integer index,AWSServiceEndpoint item);
  public AWSPlatformSpecFluent.ServiceEndpointsNested<A> editServiceEndpoint(Integer index);
  public AWSPlatformSpecFluent.ServiceEndpointsNested<A> editFirstServiceEndpoint();
  public AWSPlatformSpecFluent.ServiceEndpointsNested<A> editLastServiceEndpoint();
  public AWSPlatformSpecFluent.ServiceEndpointsNested<A> editMatchingServiceEndpoint(Predicate<AWSServiceEndpointBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ServiceEndpointsNested<N> extends Nested<N>,AWSServiceEndpointFluent<AWSPlatformSpecFluent.ServiceEndpointsNested<N>>{
    public N and();
    public N endServiceEndpoint();
    
  }
  
}

==> openshift-model-config-6.7.0-sources.jar: io/fabric8/openshift/api/model/config/v1/AWSPlatformSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface AWSPlatformSpecFluent<A extends AWSPlatformSpecFluent<A>> extends Fluent<A>{
  public A addToServiceEndpoints(int index,AWSServiceEndpoint item);
  public A setToServiceEndpoints(int index,AWSServiceEndpoint item);
  public A addToServiceEndpoints(io.fabric8.openshift.api.model.config.v1.AWSServiceEndpoint... items);
  public A addAllToServiceEndpoints(Collection<AWSServiceEndpoint> items);
  public A removeFromServiceEndpoints(io.fabric8.openshift.api.model.config.v1.AWSServiceEndpoint... items);
  public A removeAllFromServiceEndpoints(Collection<AWSServiceEndpoint> items);
  public A removeMatchingFromServiceEndpoints(Predicate<AWSServiceEndpointBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildServiceEndpoints instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<AWSServiceEndpoint> getServiceEndpoints();
  public List<AWSServiceEndpoint> buildServiceEndpoints();
  public AWSServiceEndpoint buildServiceEndpoint(int index);
  public AWSServiceEndpoint buildFirstServiceEndpoint();
  public AWSServiceEndpoint buildLastServiceEndpoint();
  public AWSServiceEndpoint buildMatchingServiceEndpoint(Predicate<AWSServiceEndpointBuilder> predicate);
  public Boolean hasMatchingServiceEndpoint(Predicate<AWSServiceEndpointBuilder> predicate);
  public A withServiceEndpoints(List<AWSServiceEndpoint> serviceEndpoints);
  public A withServiceEndpoints(io.fabric8.openshift.api.model.config.v1.AWSServiceEndpoint... serviceEndpoints);
  public Boolean hasServiceEndpoints();
  public A addNewServiceEndpoint(String name,String url);
  public AWSPlatformSpecFluent.ServiceEndpointsNested<A> addNewServiceEndpoint();
  public AWSPlatformSpecFluent.ServiceEndpointsNested<A> addNewServiceEndpointLike(AWSServiceEndpoint item);
  public AWSPlatformSpecFluent.ServiceEndpointsNested<A> setNewServiceEndpointLike(int index,AWSServiceEndpoint item);
  public AWSPlatformSpecFluent.ServiceEndpointsNested<A> editServiceEndpoint(int index);
  public AWSPlatformSpecFluent.ServiceEndpointsNested<A> editFirstServiceEndpoint();
  public AWSPlatformSpecFluent.ServiceEndpointsNested<A> editLastServiceEndpoint();
  public AWSPlatformSpecFluent.ServiceEndpointsNested<A> editMatchingServiceEndpoint(Predicate<AWSServiceEndpointBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ServiceEndpointsNested<N> extends Nested<N>,AWSServiceEndpointFluent<AWSPlatformSpecFluent.ServiceEndpointsNested<N>>{
    public N and();
    public N endServiceEndpoint();
    
  }
  
}
